@@ -148,9 +148,11 @@ class MVNMixtureModel():
         It performs a linear regression on the marginal distribution of each dimension and performs 
         a check on the x-intercept, to avoid negative values of y for x in [0,max_cov].
         '''
-        if self._default_lm:
+        if self._default_lm == True:
             return self._set_sigma_constraints()
-        return self._compute_sigma_constraints()
+
+        if self._default_lm == False:
+            return self._compute_sigma_constraints()
 
 
     def _set_sigma_constraints(self):
@@ -547,13 +549,17 @@ class MVNMixtureModel():
         self._seed = None if seed_optim else seed
         self._init_seed = None if init_seed is None else init_seed
 
+        if not self._default_lm:
+            self.hyperparameters.pop("slope")
+            self.hyperparameters.pop("intercept")
+
         if seed_optim:
             # set the guide and initialize the SVI object to minimize the initial loss 
             # for each seed in the range, it will initialize a global guide with the initialized parameters
             optim = self._settings["optim"]
             elbo = self._settings["loss"]
             _, self._seed = min([self._initialize_seed(optim, elbo, seed) for seed in range(50)], key = lambda x: x[0])
-            print("BEST SEED ", self._seed)
+            # print("BEST SEED ", self._seed)
         
         if self._seed is not None:
             pyro.set_rng_seed(self._seed)
@@ -648,6 +654,7 @@ class MVNMixtureModel():
         - `elbo` is a list with the ELBO at iteration `t` and `t-1`.
         - `p` is the percentage of ELBO s.t. `| E^(t-1) - E^(t) | < p*E^(t-1)`
         '''
+        return True
         eps = p * elbo[0]
         return abs(elbo[0] - elbo[1]) <= eps
 
@@ -684,15 +691,12 @@ class MVNMixtureModel():
         in the current step with respect to the previous one.
         '''
         par = self._normalize(par)
-        # print(eps)
         n = 0
         for k in range(par[0].shape[0]):
             for t in range(par[0].shape[1]):
                 eps = perc * par[0][k,t] # torch.max(torch.tensor(1), par[0][k,t])
                 if torch.absolute(par[0][k,t] - par[1][k,t]) <= eps:
                     n += 1
-                # else:
-                #     print(par[0][k,t], par[1][k,t], par[0][k,t] - par[1][k,t], eps * par[0][k,t])
 
         return n >= 0.9 * self.params["K"]*self.params["T"]
 
