@@ -1,34 +1,31 @@
-from os import remove
-from typing import overload
-from xml.sax.handler import all_properties
 import torch
 import pyro.distributions as distr
 import pyro
 
 
 class Simulate():
-    def __init__(self, seed, N, T, K, max_value=6000, 
+    def __init__(self, seed, N, T, K, mean_loc=500, mean_scale=5000,
         var_loc=110, var_scale=195, min_var=20, eta=1, cov_type="full",
-        label="", max_iter=100, alpha=.35):
+        label="", max_iter=100, alpha=.1):
 
         self.settings = {"N":N, "T":T, "K":K, 
-            # "mean_loc":torch.tensor(mean_loc).float(), 
-            "max_value":torch.tensor(max_value).float(),
+            "mean_loc":torch.tensor(mean_loc).float(), 
+            "mean_scale":torch.tensor(mean_scale).float(), 
+            # "max_value":torch.tensor(max_value).float(),
             "var_loc":torch.tensor(var_loc).float(), 
             "var_scale":torch.tensor(var_scale).float(), 
             "min_var":torch.tensor(min_var).float(),
             "eta":torch.tensor(eta).float(),
-            "slope":torch.tensor(0.17).float(), \
-            "intercept":torch.tensor(24.24).float(),
-            # "slope":0.09804862, "intercept":22.09327233,
-            "seed":seed, "alpha":alpha}
+            # "slope":torch.tensor(0.17).float(), \
+            # "intercept":torch.tensor(24.24).float(),
+            "alpha":alpha, "seed":seed}
 
         self._max_iter = max_iter
 
         self.cov_type = cov_type
         self.label = label
 
-        # self.set_sigma_constraints()
+    #     self.set_sigma_constraints()
 
 
     # def set_sigma_constraints(self):
@@ -49,16 +46,15 @@ class Simulate():
         K = self.settings["K"]
         T = self.settings["T"]
         N = self.settings["N"]
-        max_value = self.settings["max_value"]
-        # mean_loc = self.settings["mean_loc"]
-        # var_loc = self.settings["var_loc"]
-        # var_scale = self.settings["var_scale"]
+        
+        # max_value = self.settings["max_value"]
+        mean_loc = self.settings["mean_loc"]
+        mean_scale = self.settings["mean_scale"]
+        var_loc = self.settings["var_loc"]
+        var_scale = self.settings["var_scale"]
         min_var = self.settings["min_var"]
         eta = self.settings["eta"]
 
-        slope = self.settings["slope"]
-        intercept = self.settings["intercept"]
-
         weights = distr.Dirichlet(torch.ones(K)).sample()
         
         z = torch.zeros((N,), dtype=torch.long)
@@ -72,31 +68,24 @@ class Simulate():
         sigma_vector = torch.zeros(K,T)
         var_constr = torch.zeros(K,T)
         sigma_chol = torch.zeros((K,T,T))
-
-        # mean = distr.Uniform(0, max_value).rsample((K,T))
-
-        # sigma_vector = mean * slope + intercept + \
-        #     distr.Normal(0, 5).rsample((K,T))
-
-        # sigma_vector[sigma_vector < min_var] = min_var
-
-        # if self.cov_type == "full" and T>1:
-        #     sigma_chol = distr.LKJCholesky(T, eta).sample((K,))
         
         for k in pyro.plate("clusters", K):
 
             for t in pyro.plate("timepoints", T):
-                mean[k,t] = distr.Uniform(0, max_value).sample()
-                sigma_vector[k,t] = mean[k,t] * slope + intercept - \
-                     distr.Normal(0,10).sample().abs()
+                # mean[k,t] = distr.Uniform(0, mean_scale).sample()
+                mean[k,t] = distr.Normal(mean_loc, mean_scale).sample()
+                sigma_vector[k,t] = distr.Normal(var_loc, var_scale).sample()
 
-                if sigma_vector[k,t] < min_var: sigma_vector[k,t] = min_var
+                # check for negative values in the means
+                while mean[k,t] < 0:
+                    mean[k,t] = distr.Normal(mean_loc, mean_scale).sample()
 
-                # sigma_vector[k,t] = distr.Normal(var_loc, var_scale).sample()
-                # var_constr[k,t] = mean[k,t] * slope + intercept
-                # # check for negative values
+                # var_constr[k,t] = mean[k,t] * self.settings["slope"] + self.settings["intercept"]
+
+                # check for negative values
                 # while sigma_vector[k,t] < min_var or sigma_vector[k,t] > var_constr[k,t]:
-                #     sigma_vector[k,t] = distr.Normal(var_loc, var_scale).sample()
+                while sigma_vector[k,t] < min_var:
+                    sigma_vector[k,t] = distr.Normal(var_loc, var_scale).sample()
             
             if self.cov_type == "full" and T>1:
                 sigma_chol[k] = distr.LKJCholesky(T, eta).sample()
@@ -104,6 +93,7 @@ class Simulate():
         if self.cov_type == "diag" or T==1:
             sigma_chol = torch.eye(T) * 1.
 
+        # mean, sigma_vector, var_constr = self._check_means(mean, sigma_vector, var_constr)
         mean, sigma_vector = self._check_means(mean, sigma_vector)
 
         Sigma = self._compute_Sigma(sigma_chol, sigma_vector, K)
@@ -119,7 +109,6 @@ class Simulate():
         self.sim_id = ".".join(["N"+str(N), "T"+str(T), "K"+str(K), str(self.label)])
 
 
-
     def _check_means(self, mean, sigma_vector, n=1):
         '''
         Function to perform a check in the sampled means, to avoid overlapping 
@@ -132,14 +121,16 @@ class Simulate():
             print("MAX ITERATION")
             return mean, sigma_vector
 
-        max_value = self.settings["max_value"]
+        # max_value = self.settings["max_value"]
+        mean_loc = self.settings["mean_loc"]
+        mean_scale = self.settings["mean_scale"]
         
         min_var = self.settings["min_var"]
-        # var_loc = self.settings["var_loc"]
-        # var_scale = self.settings["var_scale"]
+        var_loc = self.settings["var_loc"]
+        var_scale = self.settings["var_scale"]
 
-        slope = self.settings["slope"]
-        intercept = self.settings["intercept"]
+        # slope = self.settings["slope"]
+        # intercept = self.settings["intercept"]
         # K = self.settings["K"]
         # T = self.settings["T"]
 
@@ -157,16 +148,17 @@ class Simulate():
 
                 while resample:
                     for tt in pyro.plate("time", self.settings["T"]):
-                        mu2[tt] = distr.Uniform(0, max_value).sample()
-                        # sigma2[tt] = distr.Normal(var_loc, var_scale).sample()
+                        # mu2[tt] = distr.Uniform(0, max_value).sample()
+                        mu2[tt] = distr.Normal(mean_loc, mean_scale).sample()
+                        sigma2[tt] = distr.Normal(var_loc, var_scale).sample()
                         # constr2[tt] = mu2[tt] * slope + intercept
                         # while sigma2[tt] < min_var or sigma2[tt] >= constr2[tt]:
-                        #     sigma2[tt] = distr.Normal(var_loc, var_scale).sample()
+                        while sigma2[tt] < min_var:
+                            sigma2[tt] = distr.Normal(var_loc, var_scale).sample()
                         
-                        sigma2[tt] = mu2[tt] * slope + intercept - \
-                            distr.Normal(0,10).sample().abs()
-
-                        if sigma2[tt] < min_var: sigma2[tt] = min_var
+                        # sigma2[tt] = mu2[tt] * slope + intercept - \
+                        #     distr.Normal(0,10).sample().abs()
+                        # if sigma2[tt] < min_var: sigma2[tt] = min_var
 
                         resample = self._do_resample(mu1, sigma1, mu2, sigma2)
                         if not resample: break
